@@ -10,16 +10,17 @@ import traceback
 from json.decoder import JSONDecodeError
 from pathlib import Path
 
+import git
 import openai
 from jsonschema import Draft7Validator
 from rich.console import Console, Text
-from rich.live import Live
 from rich.markdown import Markdown
 
 from aider import models, prompts, utils
 from aider.commands import Commands
 from aider.history import ChatSummary
 from aider.io import InputOutput
+from aider.mdstream import MarkdownStream
 from aider.repo import GitRepo
 from aider.repomap import RepoMap
 from aider.sendchat import send_with_retries
@@ -72,12 +73,11 @@ class Coder:
 
         if not skip_model_availabily_check and not main_model.always_available:
             if not check_model_availability(io, client, main_model):
-                fallback_model = models.GPT35_1106
-                if main_model != models.GPT4:
-                    io.tool_error(
-                        f"API key does not support {main_model.name}, falling back to"
-                        f" {fallback_model.name}"
-                    )
+                fallback_model = models.GPT35_0125
+                io.tool_error(
+                    f"API key does not support {main_model.name}, falling back to"
+                    f" {fallback_model.name}"
+                )
                 main_model = fallback_model
 
         if edit_format is None:
@@ -157,6 +157,15 @@ class Coder:
 
         self.commands = Commands(self.io, self, voice_language)
 
+        if use_git:
+            try:
+                self.repo = GitRepo(
+                    self.io, fnames, git_dname, aider_ignore_file, client=self.client
+                )
+                self.root = self.repo.root
+            except FileNotFoundError:
+                self.repo = None
+
         for fname in fnames:
             fname = Path(fname)
             if not fname.exists():
@@ -167,16 +176,14 @@ class Coder:
             if not fname.is_file():
                 raise ValueError(f"{fname} is not a file")
 
-            self.abs_fnames.add(str(fname.resolve()))
+            fname = str(fname.resolve())
 
-        if use_git:
-            try:
-                self.repo = GitRepo(
-                    self.io, fnames, git_dname, aider_ignore_file, client=self.client
-                )
-                self.root = self.repo.root
-            except FileNotFoundError:
-                self.repo = None
+            if self.repo and self.repo.ignored_file(fname):
+                self.io.tool_error(f"Skipping {fname} that matches aiderignore spec.")
+                continue
+
+            self.abs_fnames.add(fname)
+            self.check_added_files()
 
         if self.repo:
             rel_repo_dir = self.repo.get_rel_repo_dir()
@@ -245,6 +252,7 @@ class Coder:
 
     def add_rel_fname(self, rel_fname):
         self.abs_fnames.add(self.abs_root_path(rel_fname))
+        self.check_added_files()
 
     def abs_root_path(self, path):
         res = Path(self.root) / path
@@ -675,6 +683,10 @@ class Coder:
         if self.verbose:
             print(completion)
 
+        if not completion.choices:
+            self.io.tool_error(str(completion))
+            return
+
         show_func_err = None
         show_content_err = None
         try:
@@ -707,7 +719,8 @@ class Coder:
             tokens = f"{prompt_tokens} prompt tokens, {completion_tokens} completion tokens"
             if self.main_model.prompt_price:
                 cost = prompt_tokens * self.main_model.prompt_price / 1000
-                cost += completion_tokens * self.main_model.completion_price / 1000
+                if self.main_model.completion_price:
+                    cost += completion_tokens * self.main_model.completion_price / 1000
                 tokens += f", ${cost:.6f} cost"
                 self.total_cost += cost
 
@@ -725,14 +738,13 @@ class Coder:
             self.io.tool_output(tokens)
 
     def show_send_output_stream(self, completion):
-        live = None
         if self.show_pretty():
-            live = Live(vertical_overflow="scroll")
+            mdargs = dict(style=self.assistant_output_color, code_theme=self.code_theme)
+            mdstream = MarkdownStream(mdargs=mdargs)
+        else:
+            mdstream = None
 
         try:
-            if live:
-                live.start()
-
             for chunk in completion:
                 if len(chunk.choices) == 0:
                     continue
@@ -762,22 +774,20 @@ class Coder:
                     text = None
 
                 if self.show_pretty():
-                    self.live_incremental_response(live, False)
+                    self.live_incremental_response(mdstream, False)
                 elif text:
                     sys.stdout.write(text)
                     sys.stdout.flush()
         finally:
-            if live:
-                self.live_incremental_response(live, True)
-                live.stop()
+            if mdstream:
+                self.live_incremental_response(mdstream, True)
 
-    def live_incremental_response(self, live, final):
+    def live_incremental_response(self, mdstream, final):
         show_resp = self.render_incremental_response(final)
         if not show_resp:
             return
 
-        md = Markdown(show_resp, style=self.assistant_output_color, code_theme=self.code_theme)
-        live.update(md)
+        mdstream.update(show_resp, final=final)
 
     def render_incremental_response(self, final):
         return self.partial_response_content
@@ -854,6 +864,7 @@ class Coder:
                     self.repo.repo.git.add(full_path)
 
             self.abs_fnames.add(full_path)
+            self.check_added_files()
             return True
 
         if not self.io.confirm_ask(
@@ -866,10 +877,41 @@ class Coder:
             self.repo.repo.git.add(full_path)
 
         self.abs_fnames.add(full_path)
+        self.check_added_files()
         self.check_for_dirty_commit(path)
 
         return True
 
+    warning_given = False
+
+    def check_added_files(self):
+        if self.warning_given:
+            return
+
+        warn_number_of_files = 4
+        warn_number_of_tokens = 20 * 1024
+
+        num_files = len(self.abs_fnames)
+        if num_files < warn_number_of_files:
+            return
+
+        tokens = 0
+        for fname in self.abs_fnames:
+            relative_fname = self.get_rel_fname(fname)
+            if is_image_file(relative_fname):
+                continue
+            content = self.io.read_text(fname)
+            tokens += self.main_model.token_count(content)
+
+        if tokens < warn_number_of_tokens:
+            return
+
+        self.io.tool_error("Warning: it's best to only add files that need changes to the chat.")
+        self.io.tool_error(
+            "https://aider.chat/docs/faq.html#how-can-i-add-all-the-files-to-the-chat"
+        )
+        self.warning_given = True
+
     apply_update_errors = 0
 
     def prepare_to_edit(self, edits):
@@ -909,13 +951,18 @@ class Coder:
             self.apply_update_errors += 1
             if self.apply_update_errors < self.max_apply_update_errors:
                 self.io.tool_error(f"Malformed response #{self.apply_update_errors}, retrying...")
+                self.io.tool_error("https://aider.chat/docs/faq.html#aider-isnt-editing-my-files")
                 self.io.tool_error(str(err))
                 return None, err
             else:
                 self.io.tool_error(f"Malformed response #{self.apply_update_errors}, aborting.")
+                self.io.tool_error("https://aider.chat/docs/faq.html#aider-isnt-editing-my-files")
                 self.io.tool_error(str(err))
                 return False, None
 
+        except git.exc.GitCommandError as err:
+            self.io.tool_error(str(err))
+            return False, None
         except Exception as err:
             print(err)
             print()
