@@ -7,6 +7,7 @@ import git
 from prompt_toolkit.completion import Completion
 
 from aider import prompts, voice
+from aider.scrape import Scraper
 from aider.utils import is_gpt4_with_openai_base_url, is_image_file
 
 from .dump import dump  # noqa: F401
@@ -14,6 +15,7 @@ from .dump import dump  # noqa: F401
 
 class Commands:
     voice = None
+    scraper = None
 
     def __init__(self, io, coder, voice_language=None):
         self.io = io
@@ -25,6 +27,26 @@ class Commands:
         self.voice_language = voice_language
         self.tokenizer = coder.main_model.tokenizer
 
+    def cmd_web(self, args):
+        "Use headless selenium to scrape a webpage and add the content to the chat"
+        url = args.strip()
+        if not url:
+            self.io.tool_error("Please provide a URL to scrape.")
+            return
+
+        if not self.scraper:
+            self.scraper = Scraper(print_error=self.io.tool_error)
+
+        content = self.scraper.scrape(url) or ""
+        if content:
+            self.io.tool_output(content)
+
+        self.scraper.show_playwright_instructions()
+
+        content = f"{url}:\n\n" + content
+
+        return content
+
     def is_command(self, inp):
         return inp[0] in "/!"
 
@@ -65,7 +87,7 @@ class Commands:
 
     def run(self, inp):
         if inp.startswith("!"):
-            self.do_run("run", inp[1:])
+            return self.do_run("run", inp[1:])
             return
 
         res = self.matching_commands(inp)
@@ -202,13 +224,11 @@ class Commands:
             return
 
         last_commit = self.coder.repo.repo.head.commit
-        changed_files_last_commit = {
+        changed_files_last_commit = [
             item.a_path for item in last_commit.diff(last_commit.parents[0])
-        }
-        dirty_files = [item.a_path for item in self.coder.repo.repo.index.diff(None)]
-        dirty_files_in_last_commit = changed_files_last_commit.intersection(dirty_files)
+        ]
 
-        if dirty_files_in_last_commit:
+        if any(self.coder.repo.repo.is_dirty(path=fname) for fname in changed_files_last_commit):
             self.io.tool_error(
                 "The repository has uncommitted changes in files that were modified in the last"
                 " commit. Please commit or stash them before undoing."
@@ -242,7 +262,13 @@ class Commands:
                 " command!"
             )
             return
-        self.coder.repo.repo.git.reset("--hard", "HEAD~1")
+
+        # Reset only the files which are part of `last_commit`
+        for file_path in changed_files_last_commit:
+            self.coder.repo.repo.git.checkout("HEAD~1", file_path)
+        # Move the HEAD back before the latest commit
+        self.coder.repo.repo.git.reset("--soft", "HEAD~1")
+
         self.io.tool_output(
             f"{last_commit.message.strip()}\n"
             f"The above commit {self.coder.last_aider_commit_hash} "
@@ -320,6 +346,10 @@ class Commands:
             else:
                 fname = Path(self.coder.root) / word
 
+            if self.coder.repo and self.coder.repo.ignored_file(fname):
+                self.io.tool_error(f"Skipping {fname} that matches aiderignore spec.")
+                continue
+
             if fname.exists() and fname.is_file():
                 all_matched_files.add(str(fname))
                 continue
@@ -360,6 +390,7 @@ class Commands:
                 else:
                     self.coder.abs_fnames.add(abs_file_path)
                     self.io.tool_output(f"Added {matched_file} to the chat")
+                    self.coder.check_added_files()
                     added_fnames.append(matched_file)
 
         if not added_fnames:
@@ -428,7 +459,7 @@ class Commands:
         return self.cmd_run(args, True)
 
     def cmd_run(self, args, add_on_nonzero_exit=False):
-        "Run a shell command and optionally add the output to the chat"
+        "Run a shell command and optionally add the output to the chat (alias: !)"
         combined_output = None
         try:
             result = subprocess.run(
@@ -468,6 +499,10 @@ class Commands:
         "Exit the application"
         sys.exit()
 
+    def cmd_quit(self, args):
+        "Exit the application"
+        sys.exit()
+
     def cmd_ls(self, args):
         "List all known files and indicate which are included in the chat session"
 
