@@ -1,4 +1,5 @@
 import argparse
+import configparser
 import os
 import sys
 from pathlib import Path
@@ -45,28 +46,41 @@ def guessed_wrong_repo(io, git_root, fnames, git_dname):
 
 
 def setup_git(git_root, io):
+    repo = None
     if git_root:
-        return git_root
+        repo = git.Repo(git_root)
+    elif io.confirm_ask("No git repo found, create one to track GPT's changes (recommended)?"):
+        git_root = str(Path.cwd().resolve())
+        repo = git.Repo.init(git_root)
+        io.tool_output("Git repository created in the current working directory.")
+        check_gitignore(git_root, io, False)
 
-    if not io.confirm_ask("No git repo found, create one to track GPT's changes (recommended)?"):
+    if not repo:
         return
 
-    git_root = str(Path.cwd().resolve())
+    user_name = None
+    user_email = None
+    with repo.config_reader() as config:
+        try:
+            user_name = config.get_value("user", "name", None)
+        except configparser.NoSectionError:
+            pass
+        try:
+            user_email = config.get_value("user", "email", None)
+        except configparser.NoSectionError:
+            pass
 
-    check_gitignore(git_root, io, False)
+    if user_name and user_email:
+        return repo.working_tree_dir
 
-    repo = git.Repo.init(git_root)
-    global_git_config = git.GitConfigParser([str(Path.home() / ".gitconfig")], read_only=True)
     with repo.config_writer() as git_config:
-        if not global_git_config.has_option("user", "name"):
+        if not user_name:
             git_config.set_value("user", "name", "Your Name")
             io.tool_error('Update git name with: git config user.name "Your Name"')
-        if not global_git_config.has_option("user", "email"):
+        if not user_email:
             git_config.set_value("user", "email", "you@example.com")
             io.tool_error('Update git email with: git config user.email "you@example.com"')
 
-    io.tool_output("Git repository created in the current working directory.")
-
     return repo.working_tree_dir
 
 
@@ -142,14 +156,15 @@ def main(argv=None, input=None, output=None, force_git_root=None):
     core_group.add_argument(
         "--openai-api-key",
         metavar="OPENAI_API_KEY",
-        help="Specify the OpenAI API key",
         env_var="OPENAI_API_KEY",
+        help="Specify the OpenAI API key",
     )
+    default_model = "gpt-4-1106-preview"
     core_group.add_argument(
         "--model",
         metavar="MODEL",
-        default=models.GPT4_0613.name,
-        help=f"Specify the model to use for the main chat (default: {models.GPT4.name})",
+        default=default_model,
+        help=f"Specify the model to use for the main chat (default: {default_model})",
     )
     core_group.add_argument(
         "--skip-model-availability-check",
@@ -157,23 +172,34 @@ def main(argv=None, input=None, output=None, force_git_root=None):
         default=False,
         help="Override to skip model availability check (default: False)",
     )
-    default_4_turbo_model = models.GPT4_1106_PREVIEW
+    default_4_model = "gpt-4-0613"
     core_group.add_argument(
-        "--4-turbo",
-        "--4turbo",
         "--4",
+        "-4",
         action="store_const",
         dest="model",
-        const=default_4_turbo_model.name,
-        help=f"Use {default_4_turbo_model.name} model for the main chat (gpt-4 is better)",
+        const=default_4_model,
+        help=f"Use {default_4_model} model for the main chat",
     )
-    default_3_model = models.GPT35_1106
+    default_4_turbo_model = "gpt-4-1106-preview"
     core_group.add_argument(
+        "--4turbo",
+        "--4-turbo",
+        action="store_const",
+        dest="model",
+        const=default_4_turbo_model,
+        help=f"Use {default_4_turbo_model} model for the main chat",
+    )
+    default_3_model = models.GPT35_0125
+    core_group.add_argument(
+        "--35turbo",
+        "--35-turbo",
+        "--3",
         "-3",
         action="store_const",
         dest="model",
         const=default_3_model.name,
-        help=f"Use {default_3_model.name} model for the main chat (gpt-4 is better)",
+        help=f"Use {default_3_model.name} model for the main chat",
     )
     core_group.add_argument(
         "--voice-language",
@@ -187,23 +213,40 @@ def main(argv=None, input=None, output=None, force_git_root=None):
     model_group.add_argument(
         "--openai-api-base",
         metavar="OPENAI_API_BASE",
+        env_var="OPENAI_API_BASE",
         help="Specify the api base url",
     )
     model_group.add_argument(
         "--openai-api-type",
         metavar="OPENAI_API_TYPE",
+        env_var="OPENAI_API_TYPE",
         help="Specify the api_type",
     )
     model_group.add_argument(
         "--openai-api-version",
         metavar="OPENAI_API_VERSION",
+        env_var="OPENAI_API_VERSION",
         help="Specify the api_version",
     )
     model_group.add_argument(
         "--openai-api-deployment-id",
         metavar="OPENAI_API_DEPLOYMENT_ID",
+        env_var="OPENAI_API_DEPLOYMENT_ID",
         help="Specify the deployment_id",
     )
+    model_group.add_argument(
+        "--openai-organization-id",
+        metavar="OPENAI_ORGANIZATION_ID",
+        env_var="OPENAI_ORGANIZATION_ID",
+        help="Specify the OpenAI organization ID",
+    )
+    model_group.add_argument(
+        "--openrouter",
+        dest="openai_api_base",
+        action="store_const",
+        const="https://openrouter.ai/api/v1",
+        help="Specify the api base url as https://openrouter.ai/api/v1",
+    )
     model_group.add_argument(
         "--edit-format",
         metavar="EDIT_FORMAT",
@@ -361,6 +404,11 @@ def main(argv=None, input=None, output=None, force_git_root=None):
         help="Check for updates and return status in the exit code",
         default=False,
     )
+    other_group.add_argument(
+        "--skip-check-update",
+        action="store_true",
+        help="Skips checking for the update when the program runs",
+    )
     other_group.add_argument(
         "--apply",
         metavar="FILE",
@@ -478,7 +526,8 @@ def main(argv=None, input=None, output=None, force_git_root=None):
 
     io.tool_output(f"Aider v{__version__}")
 
-    check_version(io.tool_error)
+    if not args.skip_check_update:
+        check_version(io.tool_error)
 
     if args.check_update:
         update_available = check_version(lambda msg: None)
@@ -502,9 +551,11 @@ def main(argv=None, input=None, output=None, force_git_root=None):
         io.tool_output(show)
         io.tool_output("Option settings:")
         for arg, val in sorted(vars(args).items()):
-            io.tool_output(f"  - {arg}: {scrub_sensitive_info(str(val))}")
+            if val:
+                val = scrub_sensitive_info(str(val))
+            io.tool_output(f"  - {arg}: {val}")
 
-    io.tool_output(*sys.argv, log_only=True)
+    io.tool_output(*map(scrub_sensitive_info, sys.argv), log_only=True)
 
     if not args.openai_api_key:
         if os.name == "nt":
@@ -533,6 +584,8 @@ def main(argv=None, input=None, output=None, force_git_root=None):
                     "HTTP-Referer": "http://aider.chat",
                     "X-Title": "Aider",
                 }
+        if args.openai_organization_id:
+            kwargs["organization"] = args.openai_organization_id
 
         client = openai.OpenAI(api_key=args.openai_api_key, **kwargs)
 
